import type { InventoryDetailVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  inventoryDetailExport = '/eims/inventoryDetail/export',
  inventoryDetailList = '/eims/inventoryDetail/list',
  root = '/eims/inventoryDetail'
}

/**
 * 查询盘点列表
 * @param query
 * @returns {*}
 */

export function listInventoryDetail(params?: any) {
  return requestClient.get<InventoryDetailVO[]>(Api.inventoryDetailList, { params });
}

/**
 * 查询盘点明细
 * @param inventoryDetailId
 */
export function getInventoryDetail(inventoryDetailId: ID) {
  return requestClient.get<InventoryDetailVO>(`${Api.root}/${inventoryDetailId}`);
}

/**
 * 新增盘点明细
 * @param data
 */
export function addInventoryDetail(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改盘点明细
 * @param data
 */
export function updateInventoryDetail(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除盘点明细
 * @param inventoryId
 */
export function delInventoryDetail(inventoryDetailId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${inventoryDetailId}`);
}
/**
 * 导出
 * @param
 */
export function inventoryDetailExport(data: any) {
  return commonExport(Api.inventoryDetailExport, data);
}
